/*
Copyright (c) 2005, Pete Bevin.
<http://markdownj.petebevin.com>

All rights reserved.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions are
met:

* Redistributions of source code must retain the above copyright notice,
  this list of conditions and the following disclaimer.

* Redistributions in binary form must reproduce the above copyright
  notice, this list of conditions and the following disclaimer in the
  documentation and/or other materials provided with the distribution.

* Neither the name "Markdown" nor the names of its contributors may
  be used to endorse or promote products derived from this software
  without specific prior written permission.

This software is provided by the copyright holders and contributors "as
is" and any express or implied warranties, including, but not limited
to, the implied warranties of merchantability and fitness for a
particular purpose are disclaimed. In no event shall the copyright owner
or contributors be liable for any direct, indirect, incidental, special,
exemplary, or consequential damages (including, but not limited to,
procurement of substitute goods or services; loss of use, data, or
profits; or business interruption) however caused and on any theory of
liability, whether in contract, strict liability, or tort (including
negligence or otherwise) arising in any way out of the use of this
software, even if advised of the possibility of such damage.

*/

package com.petebevin.markdown.test;

import static org.junit.Assert.assertEquals;

import org.junit.Before;
import org.junit.Test;

import com.petebevin.markdown.MarkdownProcessor;

public class CodeBlock {
    MarkdownProcessor m;

    @Before
    public void createProcessor() {
        m = new MarkdownProcessor();
    }

    @Test
    public void testCodeBlockDefaultSetting() {
    	String md = "This is a normal paragraph.\n\n\tlang:   java\n    This is a $4 preformatted\n    code block.";
    	String expected = "<p>This is a normal paragraph.</p>\n\n<pre class=\"java\">\nThis is a $4 preformatted\ncode block.\n</pre>\n";
    	String html = m.markdown(md);
        assertEquals(expected, html);
    }

    @Test
    public void testCodeBlockCustomSetting() {
    	String tpl = "\n\n<pre class=\"brush: %s\">\n%s\n</pre>\n\n";
    	String md = "This is a normal paragraph.\n\n\tlang:   java\n    This is a $4 preformatted\n    code block.";
    	String expected = "<p>This is a normal paragraph.</p>\n\n<pre class=\"brush: java\">\nThis is a $4 preformatted\ncode block.\n</pre>\n";
    	m.setCodeBlockTemplate(tpl);
    	String html = m.markdown(md);
        assertEquals(expected, html);
    }
}
